*************************************************************************
* This do-file takes as input: main_dataset_clean.dta
* It attaches the collapsed data occ_share_wide which allows us to
* identify occupations in the top decile. 
* It then computes the numbers we need for Table 2
*************************************************************************

use "Built/main_dataset_clean.dta", clear

// Merge in data which shows which 1980 percentile each occ belongs to
merge m:1 occ1990dd using "Built/occ_share_wide", ///
	keepusing(occ_pctile1980) nogen

gen top10in80=(occ_pctile1980>=90)
* Change top10in80 to -1 for the not-working
replace top10in80=-1 if empstat!=1


log using "Built/Table2.txt", text replace

***************************************************
************* NUMBERS FOR TABLE 2 *****************
***************************************************

*** Top decile jobs, by gender

* Men - All
tab top10in80 if male==1 & year==1980 [w=perwt]
tab top10in80 if male==1 & year==2016 [w=perwt]

* Women - All
tab top10in80 if male==0 & year==1980 [w=perwt]
tab top10in80 if male==0 & year==2016 [w=perwt]

* Men, conditional on working
tab top10in80 if empstat==1 & male==1 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==1 & year==2016 [w=perwt]

* Women, conditional on working
tab top10in80 if empstat==1 & male==0 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==0 & year==2016 [w=perwt]


* Men - Non-College
tab top10in80 if male==1 & educ_grp<4 & year==1980 [w=perwt]
tab top10in80 if male==1 & educ_grp<4 & year==2016 [w=perwt]

* Women - Non-College
tab top10in80 if male==0 & educ_grp<4 & year==1980 [w=perwt]
tab top10in80 if male==0 & educ_grp<4 & year==2016 [w=perwt]

* Men, conditional on working
tab top10in80 if empstat==1 & male==1 & educ_grp<4 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==1 & educ_grp<4 & year==2016 [w=perwt]

* Women, conditional on working
tab top10in80 if empstat==1 & male==0 & educ_grp<4 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==0 & educ_grp<4 & year==2016 [w=perwt]


* Men - College
tab top10in80 if male==1 & educ_grp>=4 & year==1980 [w=perwt]
tab top10in80 if male==1 & educ_grp>=4 & year==2016 [w=perwt]

* Women - College
tab top10in80 if male==0 & educ_grp>=4 & year==1980 [w=perwt]
tab top10in80 if male==0 & educ_grp>=4 & year==2016 [w=perwt]

* Men, conditional on working
tab top10in80 if empstat==1 & male==1 & educ_grp>=4 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==1 & educ_grp>=4 & year==2016 [w=perwt]

* Women, conditional on working
tab top10in80 if empstat==1 & male==0 & educ_grp>=4 & year==1980 [w=perwt]
tab top10in80 if empstat==1 & male==0 & educ_grp>=4 & year==2016 [w=perwt]


log close	
