********************************************************************
* This do-file takes as input: occ_share_wide.dta
* It attaches task data from DOT-77 and ONET for each occ
* Output: task_chg_fem_share.dta
********************************************************************

* Create a 'local' with the DOT 1977 tasks
local tasklist reas77 math77 lang77 g_resc77 v_resc77 n_resc77 s_resc77 ///
	p_resc77 q_resc77 k_resc77 f_resc77 m_resc77 e_resc77 c_resc77 ///
	dcp77 fif77 influ77 sjc77 depl77 repcon77 pus77 sts77 varch77  


use "Built/occ_share_wide", clear


******************************
*** Merge in DOT task data ***
******************************

* Generate slightly modified occ1990dd so that codes that do not have a 
* corresponding 1970-COC code do not get lost
gen occ1990dd_mod = occ1990dd
replace occ1990dd_mod = 13  if occ1990dd == 27
replace occ1990dd_mod = 22  if occ1990dd == 4 | occ1990dd == 8 | occ1990dd == 37
replace occ1990dd_mod = 23  if occ1990dd == 24 | occ1990dd == 25  | occ1990dd == 26
replace occ1990dd_mod = 35  if occ1990dd == 558
replace occ1990dd_mod = 78  if occ1990dd == 83
replace occ1990dd_mod = 84  if occ1990dd == 106
replace occ1990dd_mod = 105  if occ1990dd == 98 | occ1990dd == 99 | occ1990dd == 103 | occ1990dd == 104
replace occ1990dd_mod = 156  if occ1990dd == 158
replace occ1990dd_mod = 183  if occ1990dd == 184
replace occ1990dd_mod = 256  if occ1990dd == 34
replace occ1990dd_mod = 258  if occ1990dd == 243
replace occ1990dd_mod = 313  if occ1990dd == 234
replace occ1990dd_mod = 319  if occ1990dd == 317 | occ1990dd == 326 | occ1990dd == 379
replace occ1990dd_mod = 335  if occ1990dd == 336 | occ1990dd == 356
replace occ1990dd_mod = 375  if occ1990dd == 377
replace occ1990dd_mod = 423  if occ1990dd == 415
replace occ1990dd_mod = 426  if occ1990dd == 427
replace occ1990dd_mod = 436  if occ1990dd == 433
replace occ1990dd_mod = 444  if occ1990dd == 439
replace occ1990dd_mod = 451  if occ1990dd == 450 | occ1990dd == 455
replace occ1990dd_mod = 453  if occ1990dd == 448
replace occ1990dd_mod = 462  if occ1990dd == 461
replace occ1990dd_mod = 469  if occ1990dd == 470
replace occ1990dd_mod = 505  if occ1990dd == 503 | occ1990dd == 507  | occ1990dd == 509
replace occ1990dd_mod = 516  if occ1990dd == 518
replace occ1990dd_mod = 535  if occ1990dd == 536
replace occ1990dd_mod = 549  if occ1990dd == 539 | occ1990dd == 543
replace occ1990dd_mod = 594  if occ1990dd == 853
replace occ1990dd_mod = 598  if occ1990dd == 614
replace occ1990dd_mod = 616  if occ1990dd == 617
replace occ1990dd_mod = 637  if occ1990dd == 684
replace occ1990dd_mod = 687  if occ1990dd == 688
replace occ1990dd_mod = 695  if occ1990dd == 694
replace occ1990dd_mod = 696  if occ1990dd == 699
replace occ1990dd_mod = 727  if occ1990dd == 729 | occ1990dd == 733
replace occ1990dd_mod = 749  if occ1990dd == 743 | occ1990dd == 747
replace occ1990dd_mod = 779  if occ1990dd == 753 | occ1990dd == 755 | occ1990dd ==757 | occ1990dd ==763 | occ1990dd ==765
replace occ1990dd_mod = 804  if occ1990dd == 803 | occ1990dd == 834
replace occ1990dd_mod = 869  if occ1990dd == 865
replace occ1990dd_mod = 889  if occ1990dd == 873 | occ1990dd ==878

gen occ_mod = (occ1990dd!=occ1990dd_mod)


* Temporarily rename occ's for merge
rename occ1990dd occ1990dd_orig
rename occ1990dd_mod occ1990dd
 
*** Merge in DOT data (see pre-cleaning files that generate DOT measures)
merge m:1 occ1990dd using "Built/dot77_occ1990dd"
tab occ1990dd if _merge==1
	* The ones that are missing in DOT are occ1990dd codes that do not have a
	* corresponding 1970-COC code and are therefore missing in the DOT dataset
tab occ1990dd if _merge==2
	* These are agriculture/farming, which we dropped from our analysis
drop if _merge!=3
drop _merge

* Change names back
rename occ1990dd occ1990dd_mod 
rename occ1990dd_orig occ1990dd 


* Following Deming, transform scale of all variables to 0-10	
foreach var in `tasklist' {
	rename `var' `var'_raw
	sum `var'_raw, meanonly
	gen `var'=`var'-r(min)
	sum `var', meanonly
	replace `var'=`var'/r(max)
	replace `var'=`var'*10
}

*** Construct social task measures ***
	foreach y in 77 {
		gen socialtasks`y' = fif`y'+influ`y'+sjc`y'+depl`y'
	}

*** Extra task variables - from Autor papers
foreach y in 77 {
	gen nr_abs`y'=(dcp`y'+math`y')/2
	gen nr_man`y'=e_resc`y'
	gen rt`y'=(sts`y'+f_resc`y')/2

	label var nr_abs`y' "Intensity in non-routine abstract (cog/int) tasks, dot-`y'"
	label var nr_man`y' "Intensity in non-routine manual tasks, dot-`y'"
	label var rt`y' "Intensity in routine (cog/man) tasks, dot-`y'"
}

* Following Deming, rescale composites
foreach var of varlist socialtasks* nr_abs* nr_man* rt* {
	rename `var' `var'_raw
	sum `var'_raw, meanonly
	gen `var'=`var'-r(min)
	sum `var', meanonly
	replace `var'=`var'/r(max)
	replace `var'=`var'*10
}


*** Normalize measures to mean zero s.d. one across occ1990dd codes 
*** (weighted using 1980 occupational employment shares)
gen aux=1
tempfile aux1 aux2 aux3
save `aux1', replace

* Gen dataset with weighted means
collapse nr_abs* nr_man* rt* socialtasks77 [w=empshare1980]
foreach y in 77 {
	foreach name in socialtasks nr_abs nr_man rt {
	rename `name'`y' mean`name'`y'
	}
}
gen aux=1
save `aux2', replace

* Gen dataset with weighted sd's
use `aux1', clear
collapse (sd) nr_abs* nr_man* rt* socialtasks77 ///
	[w=empshare1980]
foreach y in 77 {
	foreach name in socialtasks nr_abs nr_man rt {
	rename `name'`y' sd`name'`y'
	}
}
gen aux=1
save `aux3', replace

* Merge in weighted means/sd's
use `aux1', clear
merge m:1 aux using `aux2', nogen
merge m:1 aux using `aux3', nogen
drop aux

*** Normalization
foreach y in 77 {
	foreach name in socialtasks	nr_abs nr_man rt {
	rename `name'`y' `name'`y'_prenorm
	* Generate weighted mean
	gen `name'`y' = (`name'`y'_prenorm - mean`name'`y') / sd`name'`y'
	drop mean`name'`y' sd`name'`y'
	}
}

drop reas77_raw-rt77_prenorm

	
*************************************************
*** Add ONet 2002 and ONet 2016 task measures ***
*************************************************

* Merge in relevant ONet variables (as used by Deming), from 2002 and 2016 ONets


*** Generate slightly modified occ1990dd for merging to ONET because some codes do not 
* have a correspondance in ONET; give them ONET characteristics of a similar occ ***
rename occ1990dd occ1990dd_orig
gen occ1990dd=occ1990dd_orig
replace occ1990dd=22 if occ1990dd==37
replace occ1990dd=73 if occ1990dd==76
replace occ1990dd=354 if occ1990dd==346
replace occ1990dd=348 if occ1990dd==349
replace occ1990dd=423 if occ1990dd==415

foreach num in 02 {
	* From Skills module: social skill measures, one of the math measures, 
	* our extra cognitive measures, and our manual measures
merge m:1 occ1990dd using "Built/onet`num'_skill_occ1990dd", keep(1 3) ///
	keepusing(skill5_lvl_`num' skill11_lvl_`num' ///
		skill12_lvl_`num' skill13_lvl_`num' skill14_lvl_`num' ///
		skill33_lvl_`num' skill34_lvl_`num' skill35_lvl_`num')
	tab occ1990dd if _m==1
	drop _m

	* From Work Context module: routine measures
merge m:1 occ1990dd using "Built/onet`num'_wkcontext_occ1990dd", keep(1 3) ///
	keepusing(wkcontext35_`num' wkcontext37_`num')
	tab occ1990dd if _m==1
	drop _m
	
	* From Abilities module: one of the math measures
merge m:1 occ1990dd using "Built/onet`num'_abil_occ1990dd", keep(1 3) ///
	keepusing(abil12_lvl_`num' abil26_lvl_`num' abil39_lvl_`num')
	tab occ1990dd if _m==1
	drop _m
	
	* From Knowledge module: one of the math measures
merge m:1 occ1990dd using "Built/onet`num'_knowl_occ1990dd", keep(1 3) ///
	keepusing(knowl15_lvl_`num')
	tab occ1990dd if _m==1
	drop _m
}	

drop occ1990dd
rename occ1990dd_orig occ1990dd

*** Do again for 2016 where the needed aggregation is different ***
rename occ1990dd occ1990dd_orig
gen occ1990dd=occ1990dd_orig
replace occ1990dd=348 if occ1990dd==349
replace occ1990dd=423 if occ1990dd==415


foreach num in 16 {
	* From Skills module: social skill measures and one of the math measures
merge m:1 occ1990dd using "Built/onet`num'_skill_occ1990dd", keep(1 3) ///
	keepusing(skill5_lvl_`num' skill11_lvl_`num' ///
		skill12_lvl_`num' skill13_lvl_`num' skill14_lvl_`num' ///
		skill33_lvl_`num' skill34_lvl_`num' skill35_lvl_`num')
	tab occ1990dd if _m==1
	drop _m

	* From Work Context module: routine measures
merge m:1 occ1990dd using "Built/onet`num'_wkcontext_occ1990dd", keep(1 3) ///
	keepusing(wkcontext35_`num' wkcontext37_`num')
	tab occ1990dd if _m==1
	drop _m
	
	* From Abilities module: one of the math measures
merge m:1 occ1990dd using "Built/onet`num'_abil_occ1990dd", keep(1 3) ///
	keepusing(abil12_lvl_`num' abil26_lvl_`num' abil39_lvl_`num')
	tab occ1990dd if _m==1
	drop _m
	
	* From Knowledge module: one of the math measures
merge m:1 occ1990dd using "Built/onet`num'_knowl_occ1990dd", keep(1 3) ///
	keepusing(knowl15_lvl_`num')
	tab occ1990dd if _m==1
	drop _m
}		
drop occ1990dd
rename occ1990dd_orig occ1990dd


		
* Following Deming, transform scale of variables to 0-10	
foreach var of varlist skill* wkcontext* abil* knowl* {
	sum `var', meanonly
	replace `var'=`var'-r(min)
	sum `var', meanonly
	replace `var'=`var'/r(max)
	replace `var'=`var'*10
}

* Following Deming, create composites
	
foreach num in 02 16 {
* Social skills
egen socskills_onet`num'=rowmean(skill11_lvl_`num' skill12_lvl_`num' skill13_lvl_`num' skill14_lvl_`num')
drop skill11_lvl_`num' skill12_lvl_`num' skill13_lvl_`num' skill14_lvl_`num'

* Routine
egen routine_onet`num'=rowmean(wkcontext35_`num' wkcontext37_`num')
drop wkcontext35_`num' wkcontext37_`num'

* Cognitive: Average of the three math measures and the three DCP (management) questions
egen cognitive_onet`num'=rowmean(abil12_lvl_`num' skill5_lvl_`num' knowl15_lvl_`num' skill33_lvl_`num' skill34_lvl_`num' skill35_lvl_`num')
drop abil12_lvl_`num' skill5_lvl_`num' knowl15_lvl_`num' skill33_lvl_`num' skill34_lvl_`num' skill35_lvl_`num'

* Manual: Average of Abilities 26 Multilimb Coordination and 39 Gross Body Coordination
egen manual_onet`num'=rowmean(abil26_lvl_`num' abil39_lvl_`num')
drop abil26_lvl_`num' abil39_lvl_`num'
}

* Following Deming, rescale composites
foreach var in socskills_onet02 routine_onet02 cognitive_onet02 manual_onet02 ///
	socskills_onet16 routine_onet16 cognitive_onet16 manual_onet16 {
	sum `var', meanonly
	replace `var'=`var'-r(min)
	sum `var', meanonly
	replace `var'=`var'/r(max)
	replace `var'=`var'*10
}

*** Do the same normalization that we did above with DOT, i.e.:
* Normalize measures to mean zero s.d. one across occ1990dd codes 
*** (weighted using 1980 occupational employment shares)
gen aux=1
tempfile aux1 aux2 aux3
save `aux1', replace

* Gen dataset with weighted means
collapse socskills_onet* routine_onet* cognitive_onet* manual_onet* [w=empshare1980]
foreach y in 02 16 {
	foreach name in socskills_onet routine_onet cognitive_onet manual_onet {
	rename `name'`y' mean`name'`y'
	}
}
gen aux=1
save `aux2', replace

* Gen dataset with weighted sd's
use `aux1', clear
collapse (sd) socskills_onet* routine_onet* cognitive_onet* manual_onet* [w=empshare1980]
foreach y in 02 16 {
	foreach name in socskills_onet routine_onet cognitive_onet manual_onet {
	rename `name'`y' sd`name'`y'
	}
}
gen aux=1
save `aux3', replace

* Merge in weighted means/sd's
use `aux1', clear
merge m:1 aux using `aux2', nogen
merge m:1 aux using `aux3', nogen
drop aux

*** Normalization
foreach y in 02 16 {
	foreach name in socskills_onet routine_onet cognitive_onet manual_onet {
	rename `name'`y' `name'`y'_raw
	* Generate weighted mean
	gen `name'`y' = (`name'`y'_raw - mean`name'`y') / sd`name'`y'
	drop mean`name'`y' sd`name'`y'
	}
}


**********************************
*** Generate changes over time ***
**********************************

* Changes in tasks within occ, between DOT 77 and ONet 02/16
foreach dot in 77 {
foreach onet in 02 16 {
gen d`dot'`onet'socskills = socskills_onet`onet' - socialtasks`dot'
gen d`dot'`onet'routine = routine_onet`onet' - rt`dot'
gen d`dot'`onet'cognitive = cognitive_onet`onet' - nr_abs`dot'
gen d`dot'`onet'manual = manual_onet`onet' - nr_man`dot'
label var d`dot'`onet'socskills "Chg Social"
label var d`dot'`onet'cognitive  "Chg Cognit"
label var d`dot'`onet'routine "Chg Routine"
label var d`dot'`onet'manual "Chg Manual"
}
}

* Changes in propensities
foreach var in propens_f propens_m propens_col_f propens_col_m propens_noncol_f propens_noncol_m {
gen d8000_`var'=`var'2000-`var'1980
label var d8000_`var' "Change in `var' 1980-2000"
gen d0016_`var'=`var'2016-`var'2000
label var d0016_`var' "Change in `var' 2000-2016"
gen d8016_`var'=`var'2016-`var'1980
label var d8016_`var' "Change in `var' 1980-2016"
}


* Changes in Atalay measures (not available in 2016)
foreach var in ma5_deming_social ma5_deming_social_C  {
gen d_`var'=`var'2000-`var'1980
label var d_`var' "Change in `var' 1980-2000"
}

save "Built/task_chg_fem_share", replace

