 
use "Built/task_chg_fem_share", clear

****************
*** FIGURE 1 ***
****************
twoway (scatter d7716cognitive occ_pctile1980 [w=empshare1980], ///
	msymbol(circle_hollow) legend(off) mcolor(gs11)) ///
	(lfit d7716cognitive occ_pctile1980 [w=empshare1980], lc(black)), ///
	ytitle("Change in Cognitive Index") title("Cognitive") ///
	name(g1, replace) graphregion(col(white))
twoway (scatter d7716soc occ_pctile1980 [w=empshare1980], ///
	msymbol(circle_hollow) legend(off) mcolor(gs11)) ///
	(lfit d7716soc occ_pctile1980 [w=empshare1980], lc(black)), ///
	ytitle("Change in Social Skills Index") title("Social") ///
	name(g2, replace) graphregion(col(white))
twoway (scatter d7716routine occ_pctile1980 [w=empshare1980], ///
	msymbol(circle_hollow) legend(off) mcolor(gs11)) ///
	(lfit d7716routine occ_pctile1980 [w=empshare1980], lc(black)), ///
	ytitle("Change in Routine Index") title("Routine") ///
	name(g3, replace) graphregion(col(white))
twoway (scatter d7716manual occ_pctile1980 [w=empshare1980], ///
	msymbol(circle_hollow) legend(off) mcolor(gs11)) ///
	(lfit d7716manual occ_pctile1980 [w=empshare1980], lc(black)), ///
	ytitle("Change in Manual Index") title("Manual") ///
	name(g4, replace) graphregion(col(white))
graph combine g1 g2 g3 g4, graphregion(col(white)) ycom 
graph export "Built/Figure1.eps", replace



******************************************************************************************
* Generate differential propensity changes
foreach y in 00 16 {
gen dif_d80`y'_propens = 100*(d80`y'_propens_f - d80`y'_propens_m)
label var dif_d80`y'_propens "chg in propens for females - chg in propens for males"
gen dif_d80`y'_propens_col = 100*(d80`y'_propens_col_f - d80`y'_propens_col_m)
label var dif_d80`y'_propens_col "chg in propens for females - chg in propens for males"
gen dif_d80`y'_propens_noncol = 100*(d80`y'_propens_noncol_f - d80`y'_propens_noncol_m)
label var dif_d80`y'_propens_noncol "chg in propens for females - chg in propens for males"
}

* Generate propensities conditional on working
foreach g in f m {
    foreach y in 1980 2016 {
	    egen aux=sum(propens_`g'`y')
		gen propens_wrk_`g'`y'=propens_`g'`y'/aux
		drop aux
	    egen aux=sum(propens_col_`g'`y')
		gen propens_wrk_col_`g'`y'=propens_col_`g'`y'/aux
		drop aux
	    egen aux=sum(propens_noncol_`g'`y')
		gen propens_wrk_noncol_`g'`y'=propens_noncol_`g'`y'/aux
		drop aux
	}
}
gen dif_propens_wrk1980 = 100*(propens_wrk_f1980 - propens_wrk_m1980)
gen dif_propens_wrk2016 = 100*(propens_wrk_f2016 - propens_wrk_m2016)
gen dif_d8016_propens_wrk = dif_propens_wrk2016 - dif_propens_wrk1980
gen dif_d8016_propens_wrk_col = 100*((propens_wrk_col_f2016-propens_wrk_col_f1980) - (propens_wrk_col_m2016-propens_wrk_col_m1980))
gen dif_d8016_propens_wrk_noncol = 100*((propens_wrk_noncol_f2016-propens_wrk_noncol_f1980) - (propens_wrk_noncol_m2016-propens_wrk_noncol_m1980))
drop propens_wrk*

label var occ_pctile1980 "Occup Rank"
******************************************************************************************



***************
*** TABLE 1 ***
***************
rename nr_abs77 nrabs77
rename nr_man77 nrman77
foreach t in socialtasks nrabs nrman rt {
rename `t'77 `t'
}
estimates clear
eststo : reg dif_propens_wrk1980 socialtasks [w=empshare1980] 
eststo : reg dif_propens_wrk1980 socialtasks nrabs rt nrman [w=empshare1980] 
foreach t in socialtasks nrabs nrman rt {
rename `t' `t'77
}
rename socskills_onet16 socialtasks
rename cognitive_onet16 nrabs
rename manual_onet16 nrman
rename routine_onet16 rt
eststo : reg dif_propens_wrk2016 socialtasks nrabs rt nrman [w=empshare2016] 

label var socialtasks "Social"
label var nrabs "Cognitive"
label var rt "Routine"
label var nrman "Manual"
esttab * using "Built/Table1", replace rtf ///
	mtitles("1980" "1980" "2016") ///
	nocons label r2	b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nonotes ///
	title("Table 1: Relative Female-to-Male Employment Probability (Conditional on Working) and Occupational Tasks") ///
	addnotes("Notes: Data on employment probabilities from the 1980 decennial census and the 2016 American Community Survey. Data on occupational task characteristics from the 1977 Dictionary of Occupational Titles and from the 2016 O*NET. Each occupation is weighted by its share of aggregate employment in the corresponding year.")

rename socialtasks socskills_onet16
rename nrabs cognitive_onet16
rename nrman manual_onet16
rename rt routine_onet16



***************
*** TABLE 3 ***
***************
estimates clear
eststo : reg dif_d8016_propens occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_col occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_noncol occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_wrk occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_wrk_col occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_wrk_noncol occ_pctile1980 [w=empshare1980]
esttab * using "Built/Table3", replace rtf ///
	mgroups("Propensities" "Cond on Working", pattern (1 0 0 1)) ///
	mtitles("All" "College" "Non-College" "All" "College" "Non-College") ///
	varwidth(11) modelwidth(8) ///
	nocons label r2 b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nonotes ///
	title("Table 3: Correlation Between Female-vs-Male Employment Probability Changes by Occupation (1980-2016) and Occupational Wage Ranking (1980)") ///
	addnotes("Notes: Observations are at the occupation level, weighted by their aggregate employment share in 1980. The dependent variable is the differential change in the probability of working in a particular occupation for women relative to men between 1980 and 2016. Occupations are ranked by their median wage in 1980 and assigned to percentiles according to their position in the hours-weighted distribution of employment in that year. Statistical significance at * =10%, ** =5%, *** =1% levels.")

	
***************
*** TABLE 4 ***
***************
label var d_ma5_deming_social "Chg Social (DK)"
label var d_ma5_deming_social_C "Chg Social (Extended)"
rename d7716manual dman
rename d7716cognitive dcog
rename d7716routine drou
estimates clear
eststo : reg dif_d8016_propens d7716socskills [w=empshare1980]
eststo : reg dif_d8016_propens dman [w=empshare1980]
eststo : reg dif_d8016_propens d7716socskills dman [w=empshare1980]
eststo : reg dif_d8016_propens d7716socskills dman dcog drou [w=empshare1980]
eststo : reg dif_d8016_propens_noncol d7716socskills dman dcog drou [w=empshare1980]
eststo : reg dif_d8016_propens_col d7716socskills dman dcog drou [w=empshare1980]	
rename dman d7716manual
rename dcog d7716cognitive
rename drou d7716routine
rename d7702manual dman
rename d7702cognitive dcog
rename d7702routine drou

eststo : reg dif_d8000_propens d_ma5_deming_social dman dcog drou [w=empshare1980]
eststo : reg dif_d8000_propens d_ma5_deming_social_C dman dcog drou [w=empshare1980]

esttab * using "Built/Table4", replace rtf ///
	mgroups("Full Sample" "Non-College" "College" "Newspaper", pattern (1 0 0 0 1 1 1) ) ///
	order(d7716socskills d_ma5_deming_social d_ma5_deming_social_C) ///
	nocons label r2 b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nomtitles nonotes ///
	varwidth(11) modelwidth(8) ///
	title("Table 4: Differential Change in Occupational Employment Propensities for Women Relative to Men") ///
	addnotes("Notes: The dependent variable is the differential change in the probability of working in a particular occupation for women relative to men between 1980 and 2016 in Columns (1) to (6) and between 1980 and 2000 in Columns (7) and (8) based on Census and ACS data. The regressors in Columns (1) through (6) are based on occupational task characteristics from the 1977 Dictionary of Occupational Titles and the 2016 O*NET. The social task indices in Columns (7) and (8) are based on newspaper ad data from Atalay et al. (2018). Controls for other task changes in Columns (7) and (8) are based on the 1977 Dictionary of Occupational Titles and the 2002 O*NET. Occupations are weighted according to their share of aggregate employment in 1980. Statistical significance at * =10%, ** =5%, *** =1% levels.")
	
rename dman d7702manual
rename dcog d7702cognitive
rename drou d7702routine


***************
*** TABLE 5 ***
***************
// Propensity on occupational wage ranking
estimates clear
eststo : reg dif_d8016_propens occ_pctile1980 [w=empshare1980]
// Add change in social 
eststo : reg dif_d8016_propens occ_pctile1980 d7716socskills [w=empshare1980]
// Add other task changes
eststo : reg dif_d8016_propens occ_pctile1980 d7716socskills d7716manual d7716cognitive d7716routine [w=empshare1980]
// Repeat for COL and non-COL separately
eststo : reg dif_d8016_propens_col occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_col occ_pctile1980 d7716socskills [w=empshare1980]
eststo : reg dif_d8016_propens_col occ_pctile1980 d7716socskills d7716manual d7716cognitive d7716routine [w=empshare1980]
eststo : reg dif_d8016_propens_noncol occ_pctile1980 [w=empshare1980]
eststo : reg dif_d8016_propens_noncol occ_pctile1980 d7716socskills [w=empshare1980]
eststo : reg dif_d8016_propens_noncol occ_pctile1980 d7716socskills d7716manual d7716cognitive d7716routine [w=empshare1980]
esttab * using "Built/Table5", replace rtf ///
	mgroups("All" "College" "Non-College", pattern (1 0 0 1 0 0 1)) ///
	nocons label r2 b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nomtitles nonotes ///
	varwidth(11) modelwidth(7) ///
	title("Table 5: Differential Change in Occupational Employment Propensities for Women Relative to Men") ///
	addnotes("Notes: The dependent variable is the differential change in the probability of working in a particular occupation for women relative to men between 1980 and 2016. Occupational ranks are based on their position in the hours-weighted occupational wage distribution in 1980. Changes in task content are based on occupational task characteristics from the 1977 Dictionary of Occupational Titles and the 2016 O*NET. Occupations are weighted according to their share of aggregate employment in 1980. Statistical significance at * =10%, ** =5%, *** =1% levels.")

	
***************
*** TABLE 6 ***
***************
estimates clear
* Only on social, 1980
rename socialtasks77 soc
foreach g in m f {
eststo r1`g' : reg occ_coeff_`g'1980 soc [w=empshare_`g'1980]
}
* Only on social, 2016
rename soc socialtasks77 
rename socskills_onet16 soc
foreach g in m f {
eststo r2`g' : reg occ_coeff_`g'2016 soc [w=empshare_`g'2016]
}
* Add extra tasks, 1980
rename soc socskills_onet16
rename socialtasks77 soc
rename nrabs77 cog
rename rt77 rou
rename nrman77 man
foreach g in m f {
eststo r3`g' : reg occ_coeff_`g'1980 soc cog rou man [w=empshare_`g'1980]
}
* Add extra tasks, 2016
rename soc socialtasks77 
rename cog nrabs77 
rename rou rt77 
rename man nrman77
rename socskills_onet16 soc
rename cognitive_onet16 cog
rename routine_onet16 rou
rename manual_onet16 man
foreach g in m f {
eststo r4`g' : reg occ_coeff_`g'2016 soc cog rou man [w=empshare_`g'2016]
}

* Generate tables
label var soc "Social"
label var cog "Cognitive"
label var rou "Routine"
label var man "Manual"

esttab r*f using "Built/Table6_f", replace rtf ///
	mtitles("1980" "2016" "1980" "2016" "1980" "2016") ///
	nocons label r2 b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nonotes ///
	title("Table 6: Relationship between Occupational Wage Premia and Social Task Importance, Panel A: Female Occupational Wage Premia") 
	
esttab r*m using "Built/Table6_m", replace rtf ///
	mtitles("1980" "2016" "1980" "2016" "1980" "2016") ///
	nocons label r2 b(%9.3fc) se(3) star(* 0.10 ** 0.05 *** 0.01) nonotes ///
	title("Panel B: Male Occupational Wage Premia") ///
	addnotes("Notes: The dependent variable is the 3-digit occupation's year and gender-specific wage premium, obtained from individual-level regressions that control for age, education, race and nativity, using Census and ACS data. Occupations are weighted by their share of aggregate (gender-specific) employment in the corresponding year. Data on occupational task characteristics from the 1977 DOT and the 2016 O*NET. See text for details.")

rename soc socskills_onet16
rename cog cognitive_onet16
rename rou routine_onet16
rename man manual_onet16

estimates clear
