
***************************************************************************************
/* This do-file generates DOT-77 task scores at the occ1990dd level.
   It first opens the April 1971 CPS which is augmented with DOT-77 characteristics.
   occ1990dd codes are then added to the dataset by mapping 1970-COC codes to Dorn codes.
   Average DOT scores are then computed at the occ1990dd levels */
***************************************************************************************
 
 
* Create a 'local' with the list of tasks 
local tasklist reas77 math77 lang77 g77 v77 n77 s77 p77 q77 k77 f77 m77 ///
	e77 c77 g_resc77 v_resc77 n_resc77 s_resc77 p_resc77 q_resc77 k_resc77 ///
	f_resc77 m_resc77 e_resc77 c_resc77 dcp77 fif77 influ77 sjc77 mvc77  ///
	depl77 repcon77 pus77 sts77 varch77 data77 people77 things77 svp77 

	
**********************************************************************
********** APRIL 71 CPS AUGMENTED WITH DOT-77 CHARACTERISTICS ********
**********************************************************************

* This do-file builds the dataset that contains the April 1971 
* CPS augmented with 4th Edition (1977) DOT Characteristics.
* This is based on the codebook for DOT 4th Ed, p.3 onwards (p.13 of 
* PDF file). The codebook and the Stata file containing the data were 
* downloaded from ICPSR 
* ICPSR Code 07845, Data is 07845-0001

use "orig/07845-0001-Data.dta", clear

* CPS variables
rename V018 occ70
rename V023 gender
rename V029 weight

* DOT 4th Edition (1977) code
	* Note V001 has DOT 3rd Edition (1965) code
gen dot77=string(V081,"%09.0f")
   drop V081

* Extract 4th, 5th, and 6th digits (Data, People, Things)
gen data77=substr(dot77,-6,1)
gen people77=substr(dot77,-5,1)
gen things77=substr(dot77,-4,1)
foreach name in data people things { 
	destring `name'77, replace
	replace `name'77=. if `name'77==9
	label var `name' "relationship with `name', dot-77"
}
   
* GED variables
rename V082 reas77
rename V083 math77
rename V084 lang77

label var reas77 "ged-reasoning, dot-77"
label var math77 "ged-math, dot-77"
label var lang77 "ged-language, dot-77"

* SVP variable
rename V085 svp77
label var svp77 "specific vocational prep, dot-77"
label define labsvp 1 "short demo" 2 "up to 1 mo"  ///
	3 "1-3 mo" 4 "3-6 mo" 5 "6mo - 1yr" 6 "1-2 yr"  ///
	7 "2-4 yr" 8 "4-10 yr" 9 ">10 yr"
label values svp77 labsvp

* Aptitudes
rename V086 g77
rename V087 v77
rename V088 n77
rename V089 s77
rename V090 p77
rename V091 q77
rename V092 k77
rename V093 f77
rename V094 m77
rename V095 e77
rename V096 c77

label var g77 "apt-intelligence, dot-77"
label var v77 "apt-verbal, dot-77"
label var n77 "apt-numerical, dot-77"
label var s77 "apt-spacial, dot-77"
label var p77 "apt-form perception, dot-77"
label var q77 "apt-clerical, dot-77"
label var k77 "apt-motor coord, dot-77"
label var f77 "apt-finger dexterity, dot-77"
label var m77 "apt-manual dexterity, dot-77"
label var e77 "apt-eye-hand-foot coordination, dot-77"
label var c77 "apt-color discimination, dot-77"

* Temperaments
rename V097 t1
rename V098 t2
rename V099 t3
rename V100 t4
rename V101 t5

gen dcp77=0
replace dcp=1 if t1=="D"|t2=="D"|t3=="D"|t4=="D"|t5=="D" 
label var dcp77 "Direction, control, or planning, dot-77"

gen fif77=0
replace fif=1 if t1=="F"|t2=="F"|t3=="F"|t4=="F"|t5=="F"
label var fif77 "Interpretation of feelings, ideas, or facts, dot-77"

gen influ77=0
replace influ=1 if t1=="I"|t2=="I"|t3=="I"|t4=="I"|t5=="I"
label var influ77 "Influence people in opinions,attitudes,judgments, dot-77"

gen sjc77=0
replace sjc=1 if t1=="J"|t2=="J"|t3=="J"|t4=="J"|t5=="J"
label var sjc77 "Make eval or decisions based on sensory or judgmental criteria, dot-77"

gen mvc77=0
replace mvc=1 if t1=="M"|t2=="M"|t3=="M"|t4=="M"|t5=="M"
label var mvc77 "Make eval or decisions based on measurable or verifiable criteria, dot-77"

gen depl77=0
replace depl=1 if t1=="P"|t2=="P"|t3=="P"|t4=="P"|t5=="P"
label var depl77 "Dealing with people, DOT-77"

gen repcon77=0
replace repcon=1 if t1=="R"|t2=="R"|t3=="R"|t4=="R"|t5=="R"
label var repcon77 "Repetitive work or continuous performance, DOT-77"

gen pus77=0
replace pus=1 if t1=="S"|t2=="S"|t3=="S"|t4=="S"|t5=="S"
label var pus77 "Performing under stress, DOT-77"

gen sts77=0
replace sts=1 if t1=="T"|t2=="T"|t3=="T"|t4=="T"|t5=="T"
label var sts77 "Can deal w/ set limits, tolerances, or standards, dot-77"

gen varch77=0
replace varch=1 if t1=="V"|t2=="V"|t3=="V"|t4=="V"|t5=="V"
label var varch77 "Variety of duties, often changing, DOT-77"


****************** RESCALE VARIABLES ************************

*** Rescale SVP 

* Convert values to actual nr of months (see variable label for
* meaning of original codes)
rename svp77 svpraw77
gen svp77=.1 if svpraw77==1
replace svp77=.5 if svpraw77==2
replace svp77=2 if svpraw77==3
replace svp77=4.5 if svpraw77==4
replace svp77=9 if svpraw77==5
replace svp77=18 if svpraw77==6
replace svp77=36 if svpraw77==7
replace svp77=84 if svpraw77==8
replace svp77=168 if svpraw77==9 /* more than 10 yrs taken as 14 yrs */
label var svp77 "specif voc prep, nr of mo's, dot-77"


*** Rescale Aptitudes so that higher number means more important
* (see DOT source data codebook for definition of values)

foreach name in g v n s p q k f m e c {
		gen `name'_resc77=95 if `name'77==1 /* top 10% of pop */
		replace `name'_resc77=78 if `name'77==2 /* next 23% */
		replace `name'_resc77=50 if `name'77==3 /* middle third */
		replace `name'_resc77=22 if `name'77==4 /* next 23% */
		replace `name'_resc77=5 if `name'77==5 /* lowest 10% of pop */
	}
label var g_resc77 "apt-intelligence, dot-77, rescaled (5-95, incr in imp)"
label var v_resc77 "apt-verbal, dot-77, rescaled (5-95, incr in imp)"
label var n_resc77 "apt-numerical, dot-77, rescaled (5-95, incr in imp)"
label var s_resc77 "apt-spacial, dot-77, rescaled (5-95, incr in imp)"
label var p_resc77 "apt-form perception, dot-77, rescaled (5-95, incr in imp)"
label var q_resc77 "apt-clerical, dot-77, rescaled (5-95, incr in imp)"
label var k_resc77 "apt-motor coord, dot-77, rescaled (5-95, incr in imp)"
label var f_resc77 "apt-finger dexterity, dot-77, rescaled (5-95, incr in imp)"
label var m_resc77 "apt-manual dexterity, dot-77, rescaled (5-95, incr in imp)"
label var e_resc77 "apt-eye-hand-foot coordination, dot-77, rescaled (5-95, incr in imp)"
label var c_resc77 "apt-color discimination, dot-77, rescaled (5-95, incr in imp)"

**********************************************************************
**********************************************************************
**********************************************************************

****************** ATTACH occ1990dd CODES ***********************

merge m:1 occ70 using "crosswalks/occ70to_mo_dd",  ///
		keepusing(occ1990dd) nogen keep(1 3 4 5)


****************************************************************
************* GEN MEANS AT occ1990dd LEVEL *********************

collapse `tasklist' [pweight=weight], by(occ1990dd) 

do "pre-cleaning/label_tasks_77"
save "Built/dot77_occ1990dd", replace
