
* This do-file builds a dataset of the O*Net 2016 ABILITIES, KNOWLEDGE and
* SKILLS components. 
* It aggregates them to 2010 Census codes by doing a weighted average of all 
* the O*Net occ's that fall into the same 2010 Census code based on OES 
* employment data, and then aggregates to occ1990dd codes again doing a 
* weighted average of all the 2010 codes that fall into the same occ1990dd
* code using OES employment data

*************************************************************************
******************************** ONET 2016 ******************************

tempfile temp

foreach module in abil knowl skill {

if "`module'"=="abil" {
insheet using "orig/ONet 21.0 (2016)/Abilities.txt", clear
* Source: O*Net Resource Center Analyst Database;
* http://www.onetcenter.org/database.html;
* https://www.onetcenter.org/db_releases.html

* Number of dimensions in this module:
local n_dim=52
}

if "`module'"=="knowl" {
insheet using "orig/ONet 21.0 (2016)/Knowledge.txt", clear
* Number of dimensions in this module:
local n_dim=33
}

if "`module'"=="skill" {
insheet using "orig/ONet 21.0 (2016)/Skills.txt", clear
* Number of dimensions in this module:
local n_dim=35
}

keep onetsoccode elementid elementname scaleid datavalue

reshape wide datavalue, i(onetsoccode elementid) j(scaleid) string

rename datavalueLV lvl
rename datavalueIM imp

egen dim=group(elementid)

keep onetsoccode lvl imp dim

reshape wide lvl imp, i(onetsoccode) j(dim)

* Rename to make clear that it is from the corresponding module of ONet 2016
forvalues num=1/`n_dim' {
	foreach name in lvl imp {
		rename `name'`num' `module'`num'_`name'_16
	}
}

* Label variables
do "label_`module'.do"

split onetsoccode, gen(soc_) parse(- .)
	* soc_1-soc_2 are the SOC code, soc_3 is the extra bit added by ONet;
sort soc_1 soc_2
rename onetsoccode onet16


*************************************************************************
***************************** ONETs IN 2010 COC *************************
*Re-code ONet data to 2010-COC and aggregate to that level;

*** weighted collapse using employment from OES 

*** Collapse so that each soc_1 soc_2 code appears only once (i.e. combine the
* even finer occupations unique to ONet doing a simple average)
collapse *lvl* *imp*, by(soc_1 soc_2)

* Attach employment data at the SOC code level for the year 2016 from the OES:
merge 1:1 soc_1 soc_2 using "orig/OES_national_2016.dta", ///
	keepusing(tot_emp) keep(1 3) nogen
	*** The unmatched ones are:
	* 25-3099.02 Tutors
	* 45-3021.00 Hunters and Trappers

* Attach 2010 Census codes for each SOC code:
egen soc_2010=concat(soc_1 soc_2)
destring soc_2010, replace

* Match on full 6 digits
merge m:1 soc_2010 using "crosswalks/SOC2010_to_occ2010.dta", ///
	keep(1 3) keepusing(occ_2010) nogen

* Match on first 5 digits
preserve
use "crosswalks/SOC2010_to_occ2010.dta", clear
drop if soc_2010_first5==. 
save `temp', replace
restore
gen soc_2010_first5=int(soc_2010/10)
merge m:1 soc_2010_first5 using `temp', ///
	keep(1 3 4) keepusing(occ_2010) update nogen
* Match on first 3 digits
preserve
use "crosswalks/SOC2010_to_occ2010.dta", clear
drop if soc_2010_first3==. 
save `temp', replace
restore
gen soc_2010_first3=int(soc_2010/1000)
merge m:1 soc_2010_first3 using `temp', ///
	keep(1 3 4) keepusing(occ_2010) update nogen

******** MEANS BY OCC10 -- employment weighted *********
collapse *lvl* *imp* (rawsum) tot_emp [fw=tot_emp], by(occ_2010)

* Label variables
do "label_`module'.do"
label variable tot_emp "Total Employment, 2016 OES"


********************************************************************
********************** ONETs IN DORN CODES *************************
*Re-code ONet data to Dorn codes and aggregate to that level;

rename occ_2010 occ2010
merge 1:1 occ2010 using "crosswalks/occ10to_00_mo_dd.dta", ///
	keep(1 3) nogen keepusing(occ1990dd)

* Collapse by occ1990dd
collapse *lvl* *imp* (rawsum) tot_emp [fw=tot_emp], by(occ1990dd)

* Label variables
do "label_`module'.do"
label variable tot_emp "Total Employment, 2016 OES"

save "Built/onet16_`module'_occ1990dd", replace
}
